# EC-Earth3_DecadalPred-Volc

Scripts used in the manuscript submitted to Geophysical Model Development (GMD) Bilbao et al. (2025): The sensitivity of EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: Insights for the next major eruption. 

## Description
This collection of R scripts post process the data for the EC-Earth3 decadal predictions and produce the figures in the manuscript. These R script use **startR** (Automatically Retrieve Multidimensional Distributed Data Sets; https://doi.org/10.32614/CRAN.package.startR) and **s2dv** (A Set of Common Tools for Seasonal to Decadal Verification; https://doi.org/10.32614/CRAN.package.s2dv).

The EC-Earth3 decadal prediction experiments include the CMIP6 experiments dcppA-hindcast (https://doi.org/10.22033/ESGF/CMIP6.4553), dcppC-hindcast-noAgung (https://doi.org/10.22033/ESGF/CMIP6.4586), dcppC-hindcast-noElChichon (https://doi.org/10.22033/ESGF/CMIP6.4588) and dcppC-hindcast-noPinatubo (https://doi.org/10.22033/ESGF/CMIP6.4590). Three other experiments with volcanic forcing from EVA (Toohey at al., 2016) and EVA_H (https://github.com/thomasaubry/EVA_H, Aubry et al., 2020): dcppEVA, dcppEVA_H and dcppEVA_H_Carn16 are used.

Reanalysis and observational data are also used: ERA5 data is available only at https://doi.org/10.24381/cds.adbb2d47 (Hersbach et al., 2020). The Deep-C version 5 reconstructions of the radiation fluxes at the top of the atmosphere are available at https://doi.org/10.17864/1947.271 (Liu et al., 2020). The TLS (Temperature Lower Stratosphere) single-channel data set of zonally averaged temperature anomalies, produced by Remote Sensing Systems,are available at https://images.remss.com/msu/msu_time_series.html (last access: February 2025) (Mears et al., 2009).

## Abstract
Large volcanic eruptions can have significant climatic impacts. Due to their unpredictable nature, such eruptions can
render operational decadal forecasts inaccurate. To benefit from the strong climate signals they exert, which enhance climate
predictability, decadal forecasts must be rerun with updated estimates of the stratospheric sulfate aerosol evolution. Two tools
to rapidly generate the volcanic forcings are the Easy Volcanic Aerosol (EVA, Toohey et al., 2016) and its updated version,
EVA_H (Aubry et al., 2020). In order to validate the use of the volcanic forcings generated with these simple models in
decadal forecasts, we compare the volcanic forcings generated with EVA and EVA_H with CMIP6 for the recent eruptions
of Mount Agung (1963), El Chichón (1982) and Mount Pinatubo (1991) and investigate the consistency in their associated
climate responses in decadal predictions produced with the BSC decadal forecast system. Our findings reveal differences in the
magnitude and latitudinal structure of the forcings generated by EVA and EVA_H compared to the official CMIP6 forcings,
particularly for the eruptions of Mount Agung and El Chichón. These differences in the volcanic forcings lead to some global
and regional quantitative differences in the predicted radiative responses, as evidenced in variables like the top-of-atmosphere
(TOA) net radiative fluxes, surface temperature, and lower stratospheric temperature. Despite these differences, comparing the
predicted anomalies in those variables with observations, we show that either of the forcings considered allows to make skillful
predictions after the major volcanic eruptions. Our study thus supports both EVA and EVA_H generated forcings as reasonable
choices for predicting the post-volcanic radiative responses.

## Referenes

- Aubry, T. J., Toohey, M., Marshall, L., Schmidt, A., and Jellinek, A. M.: A New Volcanic Stratospheric Sulfate Aerosol Forcing Emulator (EVA_H): Comparison With Interactive Stratospheric Aerosol Models, Journal of Geophysical Research: Atmospheres, 125,
e2019JD031 303, https://doi.org/https://doi.org/10.1029/2019JD031303, e2019JD031303 10.1029/2019JD031303, 2020

- Hersbach, H., Bell, B., Berrisford, P., Hirahara, S., Horányi, A., Muñoz-Sabater, J., Nicolas, J., Peubey, C., Radu, R., Schepers, D., Simmons, A., Soci, C., Abdalla, S., Abellan, X., Balsamo, G., Bechtold, P., Biavati, G., Bidlot, J., Bonavita, M., De Chiara, G., Dahlgren,vP., Dee, D., Diamantakis, M., Dragani, R., Flemming, J., Forbes, R., Fuentes, M., Geer, A., Haimberger, L., Healy, S., Hogan, R. J., Hólm, E., Janisková, M., Keeley, S., Laloyaux, P., Lopez, P., Lupu, C., Radnoti, G., de Rosnay, P., Rozum, I., Vamborg, F., Villaume, S., and Thépaut, J.-N.: The ERA5 global reanalysis, Quarterly Journal of the Royal Meteorological Society, 146, 1999–2049, https://doi.org/https://doi.org/10.1002/qj.3803, 2020.

- Liu, C., Allan, R. P., Mayer, M., Hyder, P., Desbruyères, D., Cheng, L., Xu, J., Xu, F., and Zhang, Y.: Variability in the global energy budget and transports 1985–2017, Climate Dynamics, 55, 3381–3396, https://doi.org/10.1007/s00382-020-05451-8, 2020.

- Mears, C. A. and Wentz, F. J.: Construction of the RSS V3.2 Lower-Tropospheric Temperature Dataset from the MSU and AMSU Microwave Sounders, Journal of Atmospheric and Oceanic Technology, 26, 1493 – 1509, https://doi.org/10.1175/2009JTECHA1237.1, 2009

- Toohey, M., Stevens, B., Schmidt, H., and Timmreck, C.: Easy Volcanic Aerosol (EVA v1.0): an idealized forcing generator for climate simulations, Geoscientific Model Development, 9, 4049–4070, https://doi.org/10.5194/gmd-9-4049-2016, 2016
