################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figure 4 toa 
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(s2dv)
library(multiApply)
library(ncdf4)
library(boot)

# Path to data
pathdat = ''

#DCPP-A
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_',reg,'.nc'))
dcppA_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppA_rsdt)) = c("memb","sdate","time")
dim(dcppA_rsdt)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_',reg,'.nc'))
dcppA_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppA_rsut)) = c("memb","sdate","time")
dim(dcppA_rsut)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_',reg,'.nc'))
dcppA_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppA_rlut)) = c("memb","sdate","time")
dim(dcppA_rlut)

dcppA = dcppA_rsdt-(dcppA_rlut+dcppA_rsut)

#DCPP-C
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_',reg,'.nc'))
dcppC_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppC_rsdt)) = c("memb","sdate","time")
dim(dcppC_rsdt)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_',reg,'.nc'))
dcppC_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppC_rsut)) = c("memb","sdate","time")
dim(dcppC_rsut)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_',reg,'.nc'))
dcppC_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(dcppC_rlut)) = c("memb","sdate","time")
dim(dcppC_rlut)

dcppC = dcppC_rsdt-(dcppC_rlut+dcppC_rsut)

#EVA
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_',reg,'.nc'))
eva_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(eva_rsdt)) = c("memb","sdate","time")
dim(eva_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_',reg,'.nc'))
eva_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(eva_rlut)) = c("memb","sdate","time")
dim(eva_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_',reg,'.nc'))
eva_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(eva_rsut)) = c("memb","sdate","time")
dim(eva_rsut)

eva_dcpp = eva_rsdt-(eva_rlut+eva_rsut)

#EVAH
var = 'rsdt'
nc_data <- nc_open(paste0(path_'EC-Earth3_',var,'_EVA_H_',reg,'.nc'))
evah_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rsdt)) = c("memb","sdate","time")
dim(evah_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_',reg,'.nc'))
evah_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rlut)) = c("memb","sdate","time")
dim(evah_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_',reg,'.nc'))
evah_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rsut)) = c("memb","sdate","time")
dim(evah_rsut)

evah_dcpp = evah_rsdt-(evah_rlut+evah_rsut)

#EVA_H_Carn16
var = 'rsdt'
nc_data <- nc_open(paste0(path_'EC-Earth3_',var,'_EVA_H_Carn16_',reg,'.nc'))
evah_rsdt <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rsdt)) = c("memb","time")
dim(evah_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_Carn16_',reg,'.nc'))
evah_rlut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rlut)) = c("memb","time")
dim(evah_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_Carn16_',reg,'.nc'))
evah_rsut <- ncvar_get(nc_data, var)
nc_close(nc_data) 
names(dim(evah_rsut)) = c("memb","time")
dim(evah_rsut)

hud_dcpp = hud_rsdt-(hud_rlut+hud_rsut)

# Difference
dcpp_diff = dcppA-dcppC
eva_diff = eva_dcpp-dcppC
evah_diff = evah_dcpp-dcppC
hud_diff = hud_dcpp-dcppC[,3,]

# Ensemble mean
dcpp_diff_ens = MeanDims(dcpp_diff,'memb',na.rm = TRUE)
evah_diff_ens = MeanDims(evah_diff,'memb',na.rm = TRUE)
eva_diff_ens = MeanDims(eva_diff,'memb',na.rm = TRUE)
hud_diff_ens = MeanDims(hud_diff,'memb',na.rm = TRUE)

#Function bootstrap
signif_boot <- function(data, Rpar, memb){
# Exp with ensemble members
# Rpar - number of repetitions
# memb - number of ensemble members
bootstrap = boot(data, function(x,i) (mean(x[i=c(sample(memb,size=memb,replace=TRUE))],na.rm = TRUE)), R=Rpar)$t
q1 = apply(bootstrap, c(2), function(x) quantile(x,0.025,na.rm=TRUE))      
q2 = apply(bootstrap, c(2), function(x) quantile(x,0.975,na.rm=TRUE))      
signif <- apply(bootstrap,c(2), function(x) (quantile(x,0.025,na.rm=TRUE)>=0)||(quantile(x,0.975,na.rm=TRUE)<=0))
signif[signif == 0] = NA
return(signif)
}

Rpar=1000
nmemb=10
dcpp_boot = apply(dcpp_diff, c(2,3), function(x) (signif_boot(x,Rpar,nmemb)))
evah_boot = apply(evah_diff, c(2,3), function(x) (signif_boot(x,Rpar,nmemb)))
eva_boot = apply(eva_diff, c(2,3), function(x) (signif_boot(x,Rpar,nmemb)))
hud_boot = apply(hud_diff, c(2), function(x) (signif_boot(x,Rpar,nmemb)))

options(repr.plot.width = 12, repr.plot.height = 3, repr.plot.res = 200)
par(mfrow=c(1,3))

#PLOT
pcexlab=1.6
pcexmain=1.6
pcexax=1.6

l1 = -4
l2 = 2

#Agung
yrs = c(1:108)
plot(yrs, dcpp_diff_ens[1,], col="black", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,108), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = 'TOA (W/m^2)', main = "a) s1962, Agung", xaxt='n', xaxs="i")
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
lines((c(-5:5)*0)+3,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1963:1971), col.axis="black", cex.axis=pcexax)

polygon(c(yrs,rev(yrs)), c(dcpp_perc[1,1,],rev(dcpp_perc[2,1,])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(eva_perc[1,1,],rev(eva_perc[2,1,])),col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(evah_perc[1,1,],rev(evah_perc[2,1,])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(yrs, dcpp_diff_ens[1,], col="black")
lines(yrs, eva_diff_ens[1,], col="blue")
lines(yrs, evah_diff_ens[1,], col="red")
lines(yrs, ((yrs*0)+l1+0.3)*dcpp_boot[1,], lty=1, col="black", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1+0.15)*eva_boot[1,], lty=1, col="blue", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1)*evah_boot[1,], lty=1, col="red", lwd=0.5, type="p", pch=15, cex=0.5)

#El Chichon
yrs = c(1:108)
plot(yrs, dcpp_diff_ens[2,], col="black", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,108), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = 'TOA (W/m^2)', main = "b) s1981, El Chichon", xaxt='n', xaxs="i")
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
lines((c(-5:5)*0)+3,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1982:1990), col.axis="black", cex.axis=pcexax)

polygon(c(yrs,rev(yrs)), c(dcpp_perc[1,2,],rev(dcpp_perc[2,2,])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(eva_perc[1,2,],rev(eva_perc[2,2,])),col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(evah_perc[1,2,],rev(evah_perc[2,2,])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(yrs, dcpp_diff_ens[2,], col="black")
lines(yrs, eva_diff_ens[2,], col="blue")
lines(yrs, evah_diff_ens[2,], col="red")

lines(yrs, ((yrs*0)+l1+0.3)*dcpp_boot[2,], lty=1, col="black", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1+0.15)*eva_boot[2,], lty=1, col="blue", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1)*evah_boot[2,], lty=1, col="red", lwd=0.5, type="p", pch=15, cex=0.5)

#Pinatubo
yrs = c(1:108)
plot(yrs, dcpp_diff_ens[3,], col="black", type="l", lwd=1, ylim=c(l1,l2), xlim=c(1,108), cex.lab=pcexlab, cex.main=pcexmain, cex.axis=pcexax,
              xlab = "Time", ylab = 'TOA (W/m^2)', main = "c) s1990, Pinatubo", xaxt='n', xaxs="i")
lines(yrs,yrs*0, lty=2, col='black',lwd=1)
lines((c(-5:5)*0)+6,c(-5:5), lty=2, col='black',lwd=0.5)
axis(1, at=seq(1,108,12),labels=c(1991:1999), col.axis="black", cex.axis=pcexax)

polygon(c(yrs,rev(yrs)), c(hud_perc[1,],rev(hud_perc[2,])),col =adjustcolor("lightgreen",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(dcpp_perc[1,3,],rev(dcpp_perc[2,3,])),col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(eva_perc[1,3,],rev(eva_perc[2,3,])),col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(yrs,rev(yrs)), c(evah_perc[1,3,],rev(evah_perc[2,3,])),col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(yrs, dcpp_diff_ens[3,], col="black")
lines(yrs, eva_diff_ens[3,], col="blue")
lines(yrs, evah_diff_ens[3,], col="red")
lines(yrs, hud_diff_ens, col="darkgreen")

lines(yrs, ((yrs*0)+l1+0.45)*dcpp_boot[3,], lty=1, col="black", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1+0.3)*eva_boot[3,], lty=1, col="blue", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1+0.15)*evah_boot[3,], lty=1, col="red", lwd=0.5, type="p", pch=15, cex=0.5)
lines(yrs, ((yrs*0)+l1)*hud_boot, lty=1, col="darkgreen", lwd=0.5, type="p", pch=15, cex=0.5)


