################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figure 5
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(s2dv)
library(multiApply)
library(ncdf4)
library(boot)

# Path to data
pathdat = ''

# First month to load
t = 6

# Number of month to load
tn = 12

#DCPP-A
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_zonmean_monthly.nc'))
dcppA_rsdt <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppA_rsdt)) = c("memb","sdate","time","lat")
dim(dcppA_rsdt)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_zonmean_monthly.nc'))
dcppA_rsut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppA_rsut)) = c("memb","sdate","time","lat")
dim(dcppA_rsut)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_zonmean_monthly.nc'))
dcppA_rlut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppA_rlut)) = c("memb","sdate","time","lat")
dim(dcppA_rlut)

dcppA_dcpp = dcppA_rsdt-(dcppA_rlut+dcppA_rsut)

#DCPP-C
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_zonmean_monthly.nc'))
dcppC_rsdt <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppC_rsdt)) = c("memb","sdate","time","lat")
dim(dcppC_rsdt)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_zonmean_monthly.nc'))
dcppC_rsut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppC_rsut)) = c("memb","sdate","time","lat")
dim(dcppC_rsut)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_zonmean_monthly.nc'))
dcppC_rlut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppC_rlut)) = c("memb","sdate","time","lat")
dim(dcppC_rlut)

dcppC_dcpp = dcppC_rsdt-(dcppC_rlut+dcppC_rsut)

#EVA
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_zonmean_monthly.nc'))
eva_rsdt <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(eva_rsdt)) = c("memb","sdate","time","lat")
dim(eva_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_zonmean_monthly.nc'))
eva_rlut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(eva_rlut)) = c("memb","sdate","time","lat")
dim(eva_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_zonmean_monthly.nc'))
eva_rsut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(eva_rsut)) = c("memb","sdate","time","lat")
dim(eva_rsut)

eva_dcpp = eva_rsdt-(eva_rlut+eva_rsut)

#EVAH
var = 'rsdt'
nc_data <- nc_open(paste0(path_'EC-Earth3_',var,'_EVA_H_zonmean_monthly.nc'))
evah_rsdt <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rsdt)) = c("memb","sdate","time","lat")
dim(evah_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_zonmean_monthly.nc'))
evah_rlut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rlut)) = c("memb","sdate","time","lat")
dim(evah_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_zonmean_monthly.nc'))
evah_rsut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rsut)) = c("memb","sdate","time","lat")
dim(evah_rsut)

evah_dcpp = evah_rsdt-(evah_rlut+evah_rsut)

#EVA_H_Carn16
var = 'rsdt'
nc_data <- nc_open(paste0(path_'EC-Earth3_',var,'_EVA_H_Carn16_zonmean_monthly.nc'))
evah_rsdt <- ncvar_get(nc_data, var, start=c(1,t,1), count=c(-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rsdt)) = c("memb","time","lat")
dim(evah_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_Carn16_zonmean_monthly.nc'))
evah_rlut <- ncvar_get(nc_data, var, start=c(1,t,1), count=c(-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rlut)) = c("memb","time","lat")
dim(evah_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_Carn16_zonmean_monthly.nc'))
evah_rsut <- ncvar_get(nc_data, var, start=c(1,t,1), count=c(-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rsut)) = c("memb","time","lat")
dim(evah_rsut)

hud_dcpp = hud_rsdt-(hud_rlut+hud_rsut)

# Diff
dcpp_zon = MeanDims(dcppA-dcppC,'time')
eva_zon = MeanDims(eva_dcpp-dcppC,'time')
evah_zon = MeanDims(evah_dcpp-dcppC,'time')
evahhud_zon = MeanDims(hud_dcpp-dcppC[,3,,],'time')

dcpp_zon_ens = MeanDims(dcpp_zon,'memb')
eva_zon_ens = MeanDims(eva_zon,'memb')
evah_zon_ens = MeanDims(evah_zon,'memb')
evahhud_zon_ens = MeanDims(evahhud_zon,'memb')

#Function
signif_boot <- function(data, Rpar, memb){
# Exp with ensemble members
# Rpar - number of repetitions
# memb - number of ensemble members
bootstrap = boot(data, function(x,i) (mean(x[i=c(sample(memb,size=memb,replace=TRUE))],na.rm = TRUE)), R=Rpar)$t    
signif <- apply(bootstrap,c(2), function(x) (quantile(x,0.025,na.rm=TRUE)>=0)||(quantile(x,0.975,na.rm=TRUE)<=0))
signif[signif == 0] = NA
return(signif)
}

Rpar=1000
dcpp_boot_zon = apply(dcpp_zon, c(2,3), function(x) (signif_boot(x,Rpar,10)))
evah_boot_zon = apply(evah_zon, c(2,3), function(x) (signif_boot(x,Rpar,10)))
eva_boot_zon = apply(eva_zon, c(2,3), function(x) (signif_boot(x,Rpar,10)))
hud_boot_zon = apply(evahhud_zon, c(2), function(x) (signif_boot(x,Rpar,10)))                           

#Spread 10th and 90th percentile
dcpp_perc_zon = Apply(dcpp_zon, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
evah_perc_zon = Apply(evah_zon, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
eva_perc_zon = Apply(eva_zon, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
hud_perc_zon = Apply(evahhud_zon, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output  

options(repr.plot.width = 9, repr.plot.height = 4.5, repr.plot.res = 200)

par(mfrow=c(1,3))

#PLOT
pcexlab=1.3
pcexmain=1.3
pcexax=1.3

plot(dcpp_zon_ens[1,], lat_ecearth, col="black", type="l", lwd=0.5, ylim=c(-90,90), xlim=c(-5,5), cex.lab=pcexlab, yaxs="i",
     cex.main=pcexmain, cex.axis=pcexax, xlab = expression(TOA ~ (Wm^-2)), ylab = "Lat", main = "a) Agung", lty=1, yaxt="n")
axis(2, at = c(-90,-60,-30,0,30,60,90), las=1, cex.axis=pcexlab)

polygon(c(dcpp_perc_zon[1,1,],rev(dcpp_perc_zon[2,1,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(eva_perc_zon[1,1,],rev(eva_perc_zon[2,1,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(evah_perc_zon[1,1,],rev(evah_perc_zon[2,1,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(lat_ecearth*0,lat_ecearth, lty=2, col='black', lwd=0.5)
lines(eva_zon_ens[1,], lat_ecearth, lty=1, col='blue', lwd=0.5)
lines(evah_zon_ens[1,], lat_ecearth, lty=1, col='red', lwd=0.5)

lines(dcpp_zon_ens[1,]*dcpp_boot_zon[1,], lat_ecearth, col='black', lwd=2)
lines(eva_zon_ens[1,]*eva_boot_zon[1,], lat_ecearth, col='blue', lwd=2)
lines(evah_zon_ens[1,]*evah_boot_zon[1,], lat_ecearth, lty=1, col='red', lwd=2)

#El Chichon
plot(dcpp_zon_ens[2,], lat_ecearth, col="black", type="l", lwd=0.5, ylim=c(-90,90), xlim=c(-5,5), cex.lab=pcexlab, yaxs="i",
     cex.main=pcexmain, cex.axis=pcexax, xlab = expression(TOA ~ (Wm^-2)), ylab = "Lat", main = "b) El Chichon", lty=1, yaxt="n")
axis(2, at = c(-90,-60,-30,0,30,60,90), las=1, cex.axis=pcexlab)

polygon(c(dcpp_perc_zon[1,2,],rev(dcpp_perc_zon[2,2,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(eva_perc_zon[1,2,],rev(eva_perc_zon[2,2,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(evah_perc_zon[1,2,],rev(evah_perc_zon[2,2,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(lat_ecearth*0,lat_ecearth, lty=2, col='black', lwd=0.5)
lines(eva_zon_ens[2,], lat_ecearth, lty=1, col='blue', lwd=0.5)
lines(evah_zon_ens[2,], lat_ecearth, lty=1, col='red', lwd=0.5)

lines(dcpp_zon_ens[2,]*dcpp_boot_zon[2,], lat_ecearth, col='black', lwd=2)
lines(eva_zon_ens[2,]*eva_boot_zon[2,], lat_ecearth, col='blue', lwd=2)
lines(evah_zon_ens[2,]*evah_boot_zon[2,], lat_ecearth, lty=1, col='red', lwd=2)

plot(dcpp_zon_ens[3,], lat_ecearth, col="black", type="l", lwd=0.5, ylim=c(-90,90), xlim=c(-5,5), cex.lab=pcexlab, yaxs="i",
     cex.main=pcexmain, cex.axis=pcexax, xlab = expression(TOA ~ (Wm^-2)), ylab = "Lat", main = "c) Pinatubo", lty=1, yaxt="n")
axis(2, at = c(-90,-60,-30,0,30,60,90), las=1, cex.axis=pcexlab)

polygon(c(hud_perc_zon[1,],rev(hud_perc_zon[2,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("lightgreen",alpha.f=0.35), border = FALSE)
polygon(c(dcpp_perc_zon[1,3,],rev(dcpp_perc_zon[2,3,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(eva_perc_zon[1,3,],rev(eva_perc_zon[2,3,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(evah_perc_zon[1,3,],rev(evah_perc_zon[2,3,])), c(lat_ecearth,rev(lat_ecearth)), col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(lat_ecearth*0,lat_ecearth, lty=2, col='black', lwd=0.5)
lines(eva_zon_ens[3,], lat_ecearth, lty=1, col='blue', lwd=0.5)
lines(evah_zon_ens[3,], lat_ecearth, lty=1, col='red', lwd=0.5)
lines(evahhud_zon_ens, lat_ecearth, lty=1, col='darkgreen', lwd=0.5)

lines(dcpp_zon_ens[3,]*dcpp_boot_zon[3,], lat_ecearth, col='black', lwd=2)
lines(eva_zon_ens[3,]*eva_boot_zon[3,], lat_ecearth, col='blue', lwd=2)
lines(evah_zon_ens[3,]*evah_boot_zon[3,], lat_ecearth, lty=1, col='red', lwd=2)
lines(evahhud_zon_ens*hud_boot_zon, lat_ecearth, lty=1, col='darkgreen', lwd=2)

legend(-0.1,10, legend=c("DCPP", "DP_EVA", "DP_EVAH", "DP_EVAH-Hud"), col=c("black", "blue", "red",'darkgreen'), lty=1, 
       cex=0.9, box.lty=0, y.intersp=1.3, seg.len=0.6, lwd=2, bg="transparent")
