################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Figure 9
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(s2dv)
library(multiApply)
library(ncdf4)
library(boot)

# Path to data
pathdat = ''

# First month to load
t = 1

# Number of month to load
tn = 24

#TOA Obs
nc_data <- nc_open(paste0(pathdat,'DEEP-C_TOA_NET_v5_1985-2020.nc'))
toa <- Reorder(ncvar_get(nc_data, "NET"),c(3,2,1))
lat = ncvar_get(nc_data, "lat")
lon = ncvar_get(nc_data, "lon")
nc_close(nc_data)
names(dim(toa)) = c("time","lat","lon")
dim(toa)

#Zonal mean
zon_toa = MeanDims(toa,'lon')
dim(zon_toa)
zon_toa2 = zon_toa[1:420,]
dim(zon_toa2) = c(12,35,256)
names(dim(zon_toa2)) = c("mon","yr",'lat')
dim(zon_toa2)

#Clim
clim_zontoa = MeanDims(zon_toa2[,6:30,],'yr')
dim(clim_zontoa)

#Anom
anom_toa = zon_toa2 - InsertDim(clim_zontoa,2,35,'yr')
dim(anom_toa)

anom_toa2 = anom_toa
dim(anom_toa2) = c(420,256)
names(dim(anom_toa2)) = c("time",'lat')

anom_toa_obs_pina = anom_toa2[73:(73+120-1),]
dim(anom_toa_obs_pina)

# Timeseries
#wt = abs(lat / sum(abs(lat)))
wt = cos(lat*(pi/180))
obs_anom_ts = Apply(anom_toa_obs_pina, target_dims='lat', function(x) weighted.mean(x, wt))$output

#DCPP-A
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_zonmean_anom.nc'))
dcppA_rsdt <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppA_rsdt)) = c("memb","sdate","time","lat")
dim(dcppA_rsdt)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_zonmean_anom.nc'))
dcppA_rsut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppA_rsut)) = c("memb","sdate","time","lat")
dim(dcppA_rsut)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_zonmean_anom.nc'))
dcppA_rlut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppA_rlut)) = c("memb","sdate","time","lat")
dim(dcppA_rlut)

dcppA_dcpp = dcppA_rsdt-(dcppA_rlut+dcppA_rsut)

#DCPP-C
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_zonmean_anom.nc'))
dcppC_rsdt <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppC_rsdt)) = c("memb","sdate","time","lat")
dim(dcppC_rsdt)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_zonmean_anom.nc'))
dcppC_rsut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppC_rsut)) = c("memb","sdate","time","lat")
dim(dcppC_rsut)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_zonmean_anom.nc'))
dcppC_rlut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(dcppC_rlut)) = c("memb","sdate","time","lat")
dim(dcppC_rlut)

dcppC_dcpp = dcppC_rsdt-(dcppC_rlut+dcppC_rsut)

#EVA
var = 'rsdt'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_zonmean_anom.nc'))
eva_rsdt <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(eva_rsdt)) = c("memb","sdate","time","lat")
dim(eva_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_zonmean_anom.nc'))
eva_rlut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(eva_rlut)) = c("memb","sdate","time","lat")
dim(eva_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_zonmean_anom.nc'))
eva_rsut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(eva_rsut)) = c("memb","sdate","time","lat")
dim(eva_rsut)

eva_dcpp = eva_rsdt-(eva_rlut+eva_rsut)

#EVAH
var = 'rsdt'
nc_data <- nc_open(paste0(path_'EC-Earth3_',var,'_EVA_H_zonmean_monthly.nc'))
evah_rsdt <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rsdt)) = c("memb","sdate","time","lat")
dim(evah_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_zonmean_monthly.nc'))
evah_rlut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rlut)) = c("memb","sdate","time","lat")
dim(evah_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_zonmean_monthly.nc'))
evah_rsut <- ncvar_get(nc_data, var, start=c(1,1,t,1), count=c(-1,-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rsut)) = c("memb","sdate","time","lat")
dim(evah_rsut)

evah_dcpp = evah_rsdt-(evah_rlut+evah_rsut)

#EVA_H_Carn16
var = 'rsdt'
nc_data <- nc_open(paste0(path_'EC-Earth3_',var,'_EVA_H_Carn16_zonmean_monthly.nc'))
evah_rsdt <- ncvar_get(nc_data, var, start=c(1,t,1), count=c(-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rsdt)) = c("memb","time","lat")
dim(evah_rsdt)

var = 'rlut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_Carn16_zonmean_monthly.nc'))
evah_rlut <- ncvar_get(nc_data, var, start=c(1,t,1), count=c(-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rlut)) = c("memb","time","lat")
dim(evah_rlut)

var = 'rsut'
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_Carn16_zonmean_monthly.nc'))
evah_rsut <- ncvar_get(nc_data, var, start=c(1,t,1), count=c(-1,tn,-1))
nc_close(nc_data) 
names(dim(evah_rsut)) = c("memb","time","lat")
dim(evah_rsut)

hud_dcpp = hud_rsdt-(hud_rlut+hud_rsut)

# Global mean timeseries
wt = cos(lat*(pi/180))
dcppA_anom_ts = Apply(dcppA_anom, target_dims='lat', function(x) weighted.mean(x, wt))$output
dcppC_anom_ts = Apply(dcppC_anom, target_dims='lat', function(x) weighted.mean(x, wt))$output
evah_anom_ts = Apply(evah_anom, target_dims='lat', function(x) weighted.mean(x, wt))$output
eva_anom_ts = Apply(eva_anom, target_dims='lat', function(x) weighted.mean(x, wt))$output
hud_anom_ts = Apply(hud_anom, target_dims='lat', function(x) weighted.mean(x, wt))$output

#Ensemble mean
dcppA_anom_ts_ens = MeanDims(dcppA_anom_ts,'memb',na.rm = TRUE)
dcppC_anom_ts_ens = MeanDims(dcppC_anom_ts,'memb',na.rm = TRUE)
evah_anom_ts_ens = MeanDims(evah_anom_ts,'memb',na.rm = TRUE)
eva_anom_ts_ens = MeanDims(eva_anom_ts,'memb',na.rm = TRUE)
hud_anom_ts_ens = MeanDims(hud_anom_ts,'memb',na.rm = TRUE)

#Spread 2 10th and 90th percentile
perc_dcppA_ts = Apply(dcppA_anom_ts, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_dcppC_ts = Apply(dcppC_anom_ts, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_evah_ts = Apply(evah_anom_ts, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_eva_ts = Apply(eva_anom_ts, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_hud_ts = Apply(hud_anom_ts, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output  

# Zonal mean
dcppA_anom_ens = MeanDims(dcppA_anom,'memb',na.rm = TRUE)
dcppC_anom_ens = MeanDims(dcppC_anom,'memb',na.rm = TRUE)
evah_anom_ens = MeanDims(evah_anom,'memb',na.rm = TRUE)
eva_anom_ens = MeanDims(eva_anom,'memb',na.rm = TRUE)
hud_anom_ens = MeanDims(hud_anom,'memb',na.rm = TRUE)

#Spread 2 10th and 90th percentile
perc_dcppA = Apply(dcppA_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_dcppC = Apply(dcppC_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_evah = Apply(evah_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_eva = Apply(eva_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_hud = Apply(hud_anom, target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output  

options(repr.plot.width = 9, repr.plot.height = 4.5, repr.plot.res = 200)

par(mfrow=c(1,3))

#PLOT
pcexlab=1.3
pcexmain=1.3
pcexax=1.3

l1 = -7
l2 = 3

# Mon1-6
t1=6
t2=t1+6

plot(MeanDims(anom_toa_obs_pina[t1:t2,],'time'), lat, col="black", type="l", lwd=1, ylim=c(-90,90), xlim=c(l1,l2), cex.lab=pcexlab, 
     cex.main=pcexmain, cex.axis=pcexax, xlab = expression(TOA ~ (W/m^2)), ylab = "Lat", main = "a) Pinatubo, Mon 1-6", lty=2, yaxt="n", yaxs="i")
axis(2, at = c(-90,-60,-30,0,30,60,90), las=1, cex.axis=pcexlab)
lines(lat*0,lat, lty=2, col='black', lwd=0.5)
                
perc_dcppA = Apply(MeanDims(dcppA_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_dcppC = Apply(MeanDims(dcppC_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_evah = Apply(MeanDims(evah_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_eva = Apply(MeanDims(eva_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_hud = Apply(MeanDims(hud_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output  
polygon(c(perc_hud[1,],rev(perc_hud[2,])), c(lat,rev(lat)), col =adjustcolor("lightgreen",alpha.f=0.35), border = FALSE)
polygon(c(perc_dcppA[1,],rev(perc_dcppA[2,])), c(lat,rev(lat)), col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(perc_dcppC[1,],rev(perc_dcppC[2,])), c(lat,rev(lat)), col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(perc_eva[1,],rev(perc_eva[2,])), c(lat,rev(lat)), col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(perc_evah[1,],rev(perc_evah[2,])), c(lat,rev(lat)), col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(MeanDims(dcppA_anom_ens[t1:t2,],'time'), lat, col="black")
lines(MeanDims(dcppC_anom_ens[t1:t2,],'time'), lat, col="orange")
lines(MeanDims(eva_anom_ens[t1:t2,],'time'), lat, col="blue")
lines(MeanDims(evah_anom_ens[t1:t2,],'time'), lat, col="red")
lines(MeanDims(hud_anom_ens[t1:t2,],'time'), lat, col="darkgreen")
lines(MeanDims(anom_toa_obs_pina[t1:t2,],'time'), lat, col="black",lty=2)

legend(-7.75, 90, legend=c("Deep-C_v5","DCPP-A","DCPP-C",'DCPP-EVA',"DCPP-EVA_H","DCPP-EVA_H-Hud"),
col=c('black','black','orange','blue',"red","darkgreen"), lwd=1.5, lty=c(2,1,1,1,1,1), bty="n", 
y.intersp = 1.5, x.intersp=0.5, text.width=1, cex=0.9, seg.len=0.5)
                 
# Yr1
t1=6+6
t2=t1+6

plot(MeanDims(anom_toa_obs_pina[t1:t2,],'time'), lat, col="black", type="l", lwd=1, ylim=c(-90,90), xlim=c(l1,l2), cex.lab=pcexlab, 
     cex.main=pcexmain, cex.axis=pcexax, xlab = expression(TOA ~ (W/m^2)), ylab = "Lat", main = "b) Pinatubo, Mon 6-12", lty=2, yaxt="n", yaxs="i")
axis(2, at = c(-90,-60,-30,0,30,60,90), las=1, cex.axis=pcexlab)
lines(lat*0,lat, lty=2, col='black', lwd=0.5)

perc_dcppA = Apply(MeanDims(dcppA_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_dcppC = Apply(MeanDims(dcppC_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_evah = Apply(MeanDims(evah_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_eva = Apply(MeanDims(eva_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_hud = Apply(MeanDims(hud_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output  
polygon(c(perc_hud[1,],rev(perc_hud[2,])), c(lat,rev(lat)), col =adjustcolor("lightgreen",alpha.f=0.35), border = FALSE)
polygon(c(perc_dcppA[1,],rev(perc_dcppA[2,])), c(lat,rev(lat)), col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(perc_dcppC[1,],rev(perc_dcppC[2,])), c(lat,rev(lat)), col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(perc_eva[1,],rev(perc_eva[2,])), c(lat,rev(lat)), col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(perc_evah[1,],rev(perc_evah[2,])), c(lat,rev(lat)), col =adjustcolor("pink",alpha.f=0.35), border = FALSE)

lines(MeanDims(dcppA_anom_ens[t1:t2,],'time'), lat, col="black")
lines(MeanDims(dcppC_anom_ens[t1:t2,],'time'), lat, col="orange")
lines(MeanDims(eva_anom_ens[t1:t2,],'time'), lat, col="blue")
lines(MeanDims(evah_anom_ens[t1:t2,],'time'), lat, col="red")
lines(MeanDims(hud_anom_ens[t1:t2,],'time'), lat, col="darkgreen")
lines(MeanDims(anom_toa_obs_pina[t1:t2,],'time'), lat, col="black",lty=2)           
        
# Yr2
t1=6
t2=t1+12

plot(MeanDims(anom_toa_obs_pina[t1:t2,],'time'), lat, col="black", type="l", lwd=1, ylim=c(-90,90), xlim=c(l1,l2), cex.lab=pcexlab, 
     cex.main=pcexmain, cex.axis=pcexax, xlab = expression(TOA ~ (W/m^2)), ylab = "Lat", main = "c) Pinatubo, Yr 1", lty=2, yaxt="n", yaxs="i")
axis(2, at = c(-90,-60,-30,0,30,60,90), las=1, cex.axis=pcexlab)
lines(lat*0,lat, lty=2, col='black', lwd=0.5)

perc_dcppA = Apply(MeanDims(dcppA_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_dcppC = Apply(MeanDims(dcppC_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_evah = Apply(MeanDims(evah_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_eva = Apply(MeanDims(eva_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output
perc_hud = Apply(MeanDims(hud_anom[,t1:t2,],'time'), target_dims='memb', function(x) (quantile(x,probs = c(.1, .9),na.rm=TRUE)))$output  
polygon(c(perc_hud[1,],rev(perc_hud[2,])), c(lat,rev(lat)), col =adjustcolor("lightgreen",alpha.f=0.35), border = FALSE)
polygon(c(perc_dcppA[1,],rev(perc_dcppA[2,])), c(lat,rev(lat)), col =adjustcolor("grey",alpha.f=0.35), border = FALSE)
polygon(c(perc_dcppC[1,],rev(perc_dcppC[2,])), c(lat,rev(lat)), col =adjustcolor("lightsalmon",alpha.f=0.35), border = FALSE)
polygon(c(perc_eva[1,],rev(perc_eva[2,])), c(lat,rev(lat)), col =adjustcolor("lightblue",alpha.f=0.35), border = FALSE)
polygon(c(perc_evah[1,],rev(perc_evah[2,])), c(lat,rev(lat)), col =adjustcolor("pink",alpha.f=0.35), border = FALSE)
                 
lines(MeanDims(dcppA_anom_ens[t1:t2,],'time'), lat, col="black")
lines(MeanDims(dcppC_anom_ens[t1:t2,],'time'), lat, col="orange")
lines(MeanDims(eva_anom_ens[t1:t2,],'time'), lat, col="blue")
lines(MeanDims(evah_anom_ens[t1:t2,],'time'), lat, col="red")
lines(MeanDims(hud_anom_ens[t1:t2,],'time'), lat, col="darkgreen")
lines(MeanDims(anom_toa_obs_pina[t1:t2,],'time'), lat, col="black",lty=2)
                 
legend(-7.75, -45, legend=c("Deep-C_v5","DCPP-A","DCPP-C",'DCPP-EVA',"DCPP-EVA_H","DCPP-EVA_H-Hud"),
       col=c('black','black','orange','blue',"red","darkgreen"), lwd=1.5, lty=c(2,1,1,1,1,1), bty="n", 
       y.intersp = 1.5, x.intersp=0.5, text.width=1, cex=1, seg.len=0.5)

