################################################################################
## Script for producing figures in Bilbao et al. (2025) The sensitivity of 
## EC-Earth3 decadal predictions to the choice of volcanic forcing dataset: 
## Insights for the next major eruption.
## Script purpose: Surface temperature anomaly maps data for figure 10.
## Date: 03/2025
## Author: Roberto Bilbao (roberto.bilbao@bsc.es)
################################################################################

# Load libraries
library(ncdf4)

#Variable
var = 'tas'

# Initial month to load
t = 13

# number of months to load
tn = 12*4

# Output filename
filename = paste0(var,'_dcpp_anom_EVA_EVAH_yr2-5.Rdata')

# Path to data
pathdat = ''

#DCPP-A
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppA-hindcast_anom_latlon_1deg_monthly.nc',sep=''))
dcppA_anom <- aperm(ncvar_get(nc_data, var, start=c(1,1,1,1,t), count=c(-1,-1,-1,-1,tn)),c(3,4,5,2,1))
lon_ecearth = ncvar_get(nc_data, "longitude")
lat_ecearth = ncvar_get(nc_data, "latitude")
nc_close(nc_data)
names(dim(dcppA_anom)) = c("memb","sdate","time","latitude","longitude")
dim(dcppA_anom)

#DCPP-C
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_dcppC-hindcast_anom_latlon_1deg_monthly.nc',sep=''))
dcppC_anom <- aperm(ncvar_get(nc_data, var, start=c(1,1,1,1,t), count=c(-1,-1,-1,-1,tn)),c(3,4,5,2,1))
nc_close(nc_data)
names(dim(dcppC_anom)) = c("memb","sdate","time","latitude","longitude")
dim(dcppC_anom)

#EVA
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_anom_latlon_1deg_monthly.nc',sep=''))
eva_anom <- aperm(ncvar_get(nc_data, var, start=c(1,1,1,1,t), count=c(-1,-1,-1,-1,tn)),c(3,4,5,2,1))
nc_close(nc_data)
names(dim(eva_anom)) = c("memb","sdate","time","latitude","longitude")
dim(eva_anom)

#EVAH
nc_data <- nc_open(paste0(pathdat,'EC-Earth3_',var,'_EVA_H_anom_latlon_1deg_monthly.nc',sep=''))
evah_anom <- aperm(ncvar_get(nc_data, var, start=c(1,1,1,1,t), count=c(-1,-1,-1,-1,tn)),c(3,4,5,2,1))
nc_close(nc_data)
names(dim(evah_anom)) = c("memb","sdate","time","latitude","longitude")
dim(evah_anom)

#Save Rdata
save(dcppA_anom, dcppC_anom, eva_anom, evah_anom, lat_ecearth, lon_ecearth, file=filename)